The core part of the algorithm has been implemented in C++, using parts of the Scythe Statistical Library (2007) for matrix manipulations. Rows with missing values and constant rows are excluded.
Preinerstorfer, D. and Formann, A. K. (2012) Parameter recovery and model selection in mixed Rasch models. British Journal of Mathematical and Statistical Psychology, 65, 251-262.
Rost (1990). Rasch models in latent classes: An integration of two approaches to item analysis. Applied Psychological Measurement, 14, 271-282.